API
===

This page contains auto-generated documentation from the bidict source code.

bidict
------

.. automodule:: bidict
   :members:
   :member-order: bysource
   :special-members:
   :show-inheritance:
   :undoc-members:
   :exclude-members: __abstractmethods__,__dict__,__module__,__weakref__
   :inherited-members:


.. autodata:: bidict.RAISE
.. autodata:: bidict.OVERWRITE
.. autodata:: bidict.IGNORE

.. autofunction:: bidict._util._iteritems_mapping_or_iterable
.. autofunction:: bidict._util._iteritems_args_kw


.. attribute:: __version__

   The version of bidict represented as a string.

.. attribute:: __version_info__

   The version of bidict represented as a tuple.


bidict.compat
-------------

.. automodule:: bidict.compat
   :members:
   :member-order: bysource
   :undoc-members:
